=======
Credits
=======

Development Lead
----------------

* Lowell Alleman <lowell@kintyre.co>
* Alessandro Braidotti <alessandro@kintyre.co>

Contributors
------------

None yet. Why not be the first?
